/*!
 * Copyright 2019, OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import * as types from '@opentelemetry/types';
import { ReadableSpan } from '@opentelemetry/tracing';
import * as zipkinTypes from './types';
export declare const statusCodeTagName = "ot.status_code";
export declare const statusDescriptionTagName = "ot.status_description";
/**
 * Translate OpenTelemetry ReadableSpan to ZipkinSpan format
 * @param span Span to be translated
 */
export declare function toZipkinSpan(span: ReadableSpan, serviceName: string, statusCodeTagName: string, statusDescriptionTagName: string): zipkinTypes.Span;
/** Converts OpenTelemetry Attributes and Status to Zipkin Tags format. */
export declare function _toZipkinTags(attributes: types.Attributes, status: types.Status, statusCodeTagName: string, statusDescriptionTagName: string): zipkinTypes.Tags;
/**
 * Converts OpenTelemetry Events to Zipkin Annotations format.
 */
export declare function _toZipkinAnnotations(events: types.TimedEvent[]): zipkinTypes.Annotation[];
